@@ -334,7 +334,7 @@ if (_gps->data.fix==FIX_NOFIX) {
 	return TRUE;
 }
 _center_mode=CENTER_LATLON;
-map_center_unit(_gps->data.unitx, _gps->data.unity);
+map_center_latlon(_gps->data.lat, _gps->data.lon);
 map_update_location_from_center();
 if (map_get_zoom()>3)
 	map_set_zoom(3);
@@ -392,10 +392,8 @@ if (_center_mode > 0) {
 p=poi_find_nearest(lat, lon);
 
 if (p) {
-	guint unitx, unity;
 	gchar *banner;
 
-	latlon2unit(p->lat, p->lon, unitx, unity);
 	banner=g_strdup_printf("%s (%s)", p->label, p->cat_label);
 	g_printf("%s\n", banner);
 	MACRO_BANNER_SHOW_INFO(mapp.mainwindow, banner);
@@ -405,7 +403,7 @@ if (p) {
 	if (_center_mode > 0)
 		set_action_activate("autocenter_none", TRUE);
 
-	map_center_unit(unitx, unity);
+	map_center_latlon(p->lat, p->lon);
 	map_update_location_from_center();
 } else {
 	MACRO_BANNER_SHOW_INFO(mapp.mainwindow, _("No POIs found."));
