@@ -59,6 +59,20 @@
 #include "iap.h"
 #include "map-repo.h"
 
+/** Data used during the asynchronous progress update phase of automatic map
+ * downloading. */
+typedef struct _ProgressUpdateInfo ProgressUpdateInfo;
+struct _ProgressUpdateInfo {
+	gchar *src_str;
+	gchar *dest_str;
+	RepoData *repo;
+	guint tilex, tiley;
+	guint zoom;	/* for refresh. */
+	gint retries;		/* if equal to zero, it means we're DELETING maps. */
+	guint priority;
+	FILE *file;
+};
+
 static guint _num_downloads=0;
 static guint _curr_download=0;
 
@@ -119,6 +133,8 @@ progress_update_info_free(ProgressUpdateInfo * pui)
 {
 g_free(pui->src_str);
 g_free(pui->dest_str);
+pui->src_str=NULL;
+pui->dest_str=NULL;
 g_slice_free(ProgressUpdateInfo, pui);
 }
 
@@ -201,6 +217,7 @@ while ((msg=curl_multi_info_read(_curl_multi, &num_msgs))) {
 /* Up to 1 transfer per tile. */
 while (num_transfers < (4*4) && g_tree_nnodes(pui_tree)) {
 	ProgressUpdateInfo *pui;
+
 	g_tree_foreach(pui_tree, (GTraverseFunc)get_next_pui, &pui);
 
 	if (pui->retries) {
@@ -430,8 +447,8 @@ return NULL;
 static void 
 map_download_progress_clear(void) 
 {
-gtk_progress_bar_set_fraction(mapp.progress, 0.0);
-gtk_progress_bar_set_text(mapp.progress, "");
+gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(mapp.progress), 0.0);
+gtk_progress_bar_set_text(GTK_PROGRESS_BAR(mapp.progress), "");
 }
 
 static void 
@@ -440,14 +457,13 @@ map_download_progress_set(gint currd, gint numd)
 gchar buffer[64];
 
 g_snprintf(buffer, sizeof(buffer), "%d/%d", currd, numd);
-gtk_progress_bar_set_text(mapp.progress, buffer);	
-gtk_progress_bar_set_fraction(mapp.progress, (gdouble)currd/(gdouble)numd);
+gtk_progress_bar_set_text(GTK_PROGRESS_BAR(mapp.progress), buffer);	
+gtk_progress_bar_set_fraction(GTK_PROGRESS_BAR(mapp.progress), (gdouble)currd/(gdouble)numd);
 }
 
 static gboolean 
 map_download_idle_refresh(ProgressUpdateInfo * pui)
 {
-guint tmp=0;
 /* Test if download succeeded (only if retries != 0). */
 if (!pui->retries || g_file_test(pui->dest_str, G_FILE_TEST_EXISTS)) {
 	gchar *key;
@@ -528,7 +544,7 @@ if (iap_is_connected() && !_curl_sid)
 	_curl_sid=g_idle_add((GSourceFunc)map_download_timeout, NULL);
 
 if (!_num_downloads++)
-	gtk_progress_bar_set_text(mapp.progress, _("Downloading maps..."));
+	gtk_progress_bar_set_text(GTK_PROGRESS_BAR(mapp.progress), _("Downloading maps..."));
 }
 
 void
