@@ -797,6 +797,12 @@ guint unitx, unity;
 
 latlon2unit(lat, lon, unitx, unity);
 map_center_unit(unitx, unity);
+if (_gps->io.conn!=RCVR_FIXED) {
+	_gps->data.lat=lat;
+	_gps->data.lon=lon;
+	_gps->data.unitx=unitx;
+	_gps->data.unity=unity;
+}
 }
 
 /**
@@ -1395,7 +1401,7 @@ if (!s && !mp && !sp) {
 	gdouble lat, lon;
 
 	unit2latlon(_center.unitx, _center.unity, lat, lon);
-	g_snprintf(buffer_r, sizeof(buffer_r), "<span size='larger' weight='bold'> %.06f,%.06f </span>", lat, lon);
+	g_snprintf(buffer_r, sizeof(buffer_r), "<span size='larger' weight='bold'>%.06f %.06f</span>", lat, lon);
 	gtk_label_set_markup(GTK_LABEL(mapp.ib.location_name), buffer_r);
 	gtk_label_set_markup(GTK_LABEL(mapp.ib.location_intref), "");
 	gtk_label_set_markup(GTK_LABEL(mapp.ib.location_ref), "");
@@ -1525,7 +1531,6 @@ gtk_label_set_label(GTK_LABEL(mapp.ib.distance), buffer);
 static gboolean
 map_refresh_place_information(gpointer data)
 {
-g_debug("Getting place info");
 osm_get_location_place_data(&map_loc);
 if (map_loc.valid)
 	map_set_place_information(map_loc.street, map_loc.primary, map_loc.secondary);
